@@ -3,6 +3,7 @@ import ovh.exceptions
 from ovh_iplb.utils import build_path, clean_unicode_of_dict, convert_key_to_camel_case
 import time
 import itertools
+from ovh_iplb.parralized_client import ParralizedClient
 
 
 def _real_payload_ok_with_wanted_payload(real_payload, wanted_payload):
@@ -54,9 +55,15 @@ class Resource(object):
 
         return self.client().delete(self.path(*arg))
 
-    def subresource(self, subresource_name):
-        return [self.get(subresource_name, id)
-                for id in self.get(subresource_name)]
+    def subresource(self, subresource_name, no_cache=False):
+        self._subresource_cache = getattr(self, '_subresource_cache', {})
+        if no_cache or subresource_name not in self._subresource_cache:
+            self._subresource_cache[subresource_name] = self.client().multiget(
+                self.path(subresource_name, id)
+                for id in self.get(subresource_name)
+            )
+
+        return self._subresource_cache[subresource_name]
 
     def unique_field_value(self):
         return self.body()[self.unique_field]
@@ -98,7 +105,10 @@ class Resource(object):
             raise ValueError('Could not update %s that does not exist' % (self.resource_name,))
         real_body = self.read()
         wanted_body = self.body()
-        changement = not _real_payload_ok_with_wanted_payload(real_payload=real_body, wanted_payload=wanted_body)
+        changement = not _real_payload_ok_with_wanted_payload(
+            real_payload=self.transform_body_before_compare(real_body),
+            wanted_payload=self.transform_body_before_compare(wanted_body))
+
         if changement:
             self.client().put(self.path(), **wanted_body)
         return changement
@@ -109,6 +119,9 @@ class Resource(object):
         self.create()
         return True
 
+    def transform_body_before_compare(self, body):
+        return body
+
 
 class Server(Resource):
 
@@ -158,6 +171,10 @@ class Frontend(Resource):
 
         return convert_key_to_camel_case(body)
 
+    def transform_body_before_compare(self, body):
+        return {k: set(v) if k == 'allowedSource' else v
+                for (k, v) in body.items()}
+
     def name(self):
         return self.frontend_def.get('name', None)
 
@@ -229,10 +246,10 @@ class Farm(Resource):
 class IPLB(Resource):
     def __init__(self, iplb_def):
         self.iplb_def = iplb_def
-        self._client = ovh.Client(endpoint=iplb_def['endpoint'],
-                                  application_key=iplb_def['application_key'],
-                                  application_secret=iplb_def['application_secret'],
-                                  consumer_key=iplb_def['consumer_key'])
+        self._client = ParralizedClient(ovh.Client(endpoint=iplb_def['endpoint'],
+                                                   application_key=iplb_def['application_key'],
+                                                   application_secret=iplb_def['application_secret'],
+                                                   consumer_key=iplb_def['consumer_key']))
         self._farms = None
 
     def id(self):
@@ -283,8 +300,9 @@ class IPLB(Resource):
         return self._client
 
     def task_in_progress(self):
+        tasks = self.subresource('task', no_cache=True)
         return len(tuple(
-            filter(lambda task: task['status'] != 'done', self.subresource('task'))
+            filter(lambda task: task['status'] != 'done', tasks)
         )) > 0
 
     def refresh(self):
