@@ -51,7 +51,7 @@ class PrepareMockedIPLB(object):
 
         self.iplb = iplb_client.IPLB(dict(iplb_id='iplb_id', timeout=2, **iplb_secret))
         ovh.assert_called_with(**iplb_secret)
-        self.mocked_client_instance = self.iplb._client
+        self.mocked_client_instance = self.iplb._client._client
 
     def mock_get(self, dic):
         def side_effect(path):
@@ -102,6 +102,23 @@ class TestIplb(PrepareMockedIPLB, unittest.TestCase):
 
         self.assertFalse(self.iplb.task_in_progress())
 
+    def test_task_in_progress_when_task_move_from_not_done_to_done(self):
+        self.mock_get({
+            '/ipLoadbalancing/iplb_id/task': [1, 2],
+            '/ipLoadbalancing/iplb_id/task/1': {'status': 'doing'},
+            '/ipLoadbalancing/iplb_id/task/2': {'status': 'done'},
+        })
+
+        self.assertTrue(self.iplb.task_in_progress())
+
+        self.mock_get({
+            '/ipLoadbalancing/iplb_id/task': [1, 2],
+            '/ipLoadbalancing/iplb_id/task/1': {'status': 'done'},
+            '/ipLoadbalancing/iplb_id/task/2': {'status': 'done'},
+        })
+
+        self.assertFalse(self.iplb.task_in_progress())
+
     def test_is_refresh_needed_when_no_pending_change(self):
         self.mock_get({
             '/ipLoadbalancing/iplb_id/pendingChanges': [],
@@ -157,6 +174,42 @@ class TestFrontend(PrepareMockedIPLB, unittest.TestCase):
             'default_farm_name': 'farm_name'
         }).exist())
 
+    def test_update_when_allowed_source_not_in_same_order_should_do_no_update(self):
+        self.mock_get({
+            '/ipLoadbalancing/iplb_id/tcp/frontend/42': {'frontendId': 42,
+                                                         'displayName': 'name',
+                                                         'type': 'tcp',
+                                                         'allowedSource': ['10.8.4.4/28', '9.8.4.4/28']},
+            '/ipLoadbalancing/iplb_id/tcp/frontend/41': {'frontendId': 41, 'displayName': 'otherName'},
+            '/ipLoadbalancing/iplb_id/tcp/frontend': ['41', '42']
+        })
+
+        self.assertFalse(self.iplb.frontend({
+            'type': 'tcp',
+            'name': 'name',
+            'allowed_source': ['9.8.4.4/28', '10.8.4.4/28']
+        }).update())
+        self.mocked_client_instance.put.assert_not_called
+
+    def test_update_when_allowed_source_are_not_the_same_should_update(self):
+        self.mock_get({
+            '/ipLoadbalancing/iplb_id/tcp/frontend/42': {'frontendId': 42,
+                                                         'displayName': 'name',
+                                                         'type': 'tcp',
+                                                         'allowedSource': ['10.8.4.4/32', '9.8.4.4/28']},
+            '/ipLoadbalancing/iplb_id/tcp/frontend/41': {'frontendId': 41, 'displayName': 'otherName'},
+            '/ipLoadbalancing/iplb_id/tcp/frontend': ['41', '42']
+        })
+
+        self.assertTrue(self.iplb.frontend({
+            'type': 'tcp',
+            'name': 'name',
+            'allowed_source': ['9.8.4.4/28', '10.8.4.4/28']
+        }).update())
+        self.mocked_client_instance.put.assert_called_with('/ipLoadbalancing/iplb_id/tcp/frontend/42',
+                                                           displayName='name',
+                                                           allowedSource=['9.8.4.4/28', '10.8.4.4/28'])
+
     def test_exist_with_unexisting_name(self):
         self.mock_get({
             '/ipLoadbalancing/iplb_id/tcp/frontend/42': {'frontendId': 42, 'displayName': 'name'},
@@ -188,7 +241,6 @@ class TestFrontend(PrepareMockedIPLB, unittest.TestCase):
                 'type': 'tcp',
                 'name': 'name',
                 'default_farm_name': 'name'
-
             }).exist()
 
     def test_create_should_fail_when_no_farm_with_given_name_exist(self):
